( cd usr/openwin/bin ; rm -rf shelltool )
( cd usr/openwin/bin ; ln -sf  cmdtool shelltool )
( cd usr/openwin/lib ; rm -rf text_extras_menu )
( cd usr/openwin/lib ; ln -sf  .text_extras_menu text_extras_menu )
( cd usr/openwin/lib ; rm -rf textswrc )
( cd usr/openwin/lib ; ln -sf  .textswrc textswrc )
( cd usr/openwin/lib ; rm -rf ttyswrc )
( cd usr/openwin/lib ; ln -sf  .ttyswrc ttyswrc )
( cd usr/openwin/lib ; rm -rf Xinitrc )
( cd usr/openwin/lib ; ln -sf  /var/openwin/lib/Xinitrc Xinitrc )
( cd usr/openwin/bin ; rm -rf xgettext )
( cd usr/openwin/bin ; ln -sf /cdrom/live/usr/openwin/bin/xgettext xgettext )
( cd usr/openwin/bin ; rm -rf msgfmt )
( cd usr/openwin/bin ; ln -sf /cdrom/live/usr/openwin/bin/msgfmt msgfmt )
( cd usr/openwin/bin ; rm -rf olwm )
( cd usr/openwin/bin ; ln -sf /cdrom/live/usr/openwin/bin/olwm olwm )
( cd usr/openwin/bin ; rm -rf svenv )
( cd usr/openwin/bin ; ln -sf /cdrom/live/usr/openwin/bin/svenv svenv )
( cd usr/openwin/bin ; rm -rf toolwait )
( cd usr/openwin/bin ; ln -sf /cdrom/live/usr/openwin/bin/toolwait toolwait )
( cd usr/openwin/bin ; rm -rf winsysck )
( cd usr/openwin/bin ; ln -sf /cdrom/live/usr/openwin/bin/winsysck winsysck )
( cd usr/openwin/bin ; rm -rf owplaces )
( cd usr/openwin/bin ; ln -sf /cdrom/live/usr/openwin/bin/owplaces owplaces )
( cd usr/openwin/bin ; rm -rf openwin )
( cd usr/openwin/bin ; ln -sf /cdrom/live/usr/openwin/bin/openwin openwin )
( cd usr/openwin/bin ; rm -rf xcenter )
( cd usr/openwin/bin ; ln -sf /cdrom/live/usr/openwin/bin/xcenter xcenter )
( cd usr/openwin/bin ; rm -rf clock )
( cd usr/openwin/bin ; ln -sf /cdrom/live/usr/openwin/bin/clock clock )
( cd usr/openwin/bin ; rm -rf cmdtool )
( cd usr/openwin/bin ; ln -sf /cdrom/live/usr/openwin/bin/cmdtool cmdtool )
( cd usr/openwin/bin ; rm -rf olwmslave )
( cd usr/openwin/bin ; ln -sf /cdrom/live/usr/openwin/bin/olwmslave olwmslave )
( cd usr/openwin/bin ; rm -rf props )
( cd usr/openwin/bin ; ln -sf /cdrom/live/usr/openwin/bin/props props )
( cd usr/openwin/bin ; rm -rf textedit )
( cd usr/openwin/bin ; ln -sf /cdrom/live/usr/openwin/bin/textedit textedit )
( cd usr/openwin/bin ; rm -rf olvwm )
( cd usr/openwin/bin ; ln -sf /cdrom/live/usr/openwin/bin/olvwm olvwm )
( cd usr/openwin/bin ; rm -rf xtoolplaces )
( cd usr/openwin/bin ; ln -sf /cdrom/live/usr/openwin/bin/xtoolplaces xtoolplaces )
( cd usr/openwin/bin ; rm -rf meminfo )
( cd usr/openwin/bin ; ln -sf /cdrom/live/usr/openwin/bin/meminfo meminfo )
( cd usr/openwin/etc ; rm -rf lxxview.xbm )
( cd usr/openwin/etc ; ln -sf /cdrom/live/usr/openwin/etc/lxxview.xbm lxxview.xbm )
( cd usr/openwin/etc ; rm -rf README.linux )
( cd usr/openwin/etc ; ln -sf /cdrom/live/usr/openwin/etc/README.linux README.linux )
( cd usr/openwin/etc ; rm -rf xview3L5.announce )
( cd usr/openwin/etc ; ln -sf /cdrom/live/usr/openwin/etc/xview3L5.announce xview3L5.announce )
( cd usr/openwin/man/man1 ; rm -rf xview.1x )
( cd usr/openwin/man/man1 ; ln -sf /cdrom/live/usr/openwin/man/man1/xview.1x xview.1x )
( cd usr/openwin/man/man1 ; rm -rf xgettext.1 )
( cd usr/openwin/man/man1 ; ln -sf /cdrom/live/usr/openwin/man/man1/xgettext.1 xgettext.1 )
( cd usr/openwin/man/man1 ; rm -rf msgfmt.1 )
( cd usr/openwin/man/man1 ; ln -sf /cdrom/live/usr/openwin/man/man1/msgfmt.1 msgfmt.1 )
( cd usr/openwin/man/man1 ; rm -rf clock.1x )
( cd usr/openwin/man/man1 ; ln -sf /cdrom/live/usr/openwin/man/man1/clock.1x clock.1x )
( cd usr/openwin/man/man1 ; rm -rf cmdtool.1x )
( cd usr/openwin/man/man1 ; ln -sf /cdrom/live/usr/openwin/man/man1/cmdtool.1x cmdtool.1x )
( cd usr/openwin/man/man1 ; rm -rf shelltool.1x )
( cd usr/openwin/man/man1 ; ln -sf /cdrom/live/usr/openwin/man/man1/shelltool.1x shelltool.1x )
( cd usr/openwin/man/man1 ; rm -rf olwm.1x )
( cd usr/openwin/man/man1 ; ln -sf /cdrom/live/usr/openwin/man/man1/olwm.1x olwm.1x )
( cd usr/openwin/man/man1 ; rm -rf olwmslave.1x )
( cd usr/openwin/man/man1 ; ln -sf /cdrom/live/usr/openwin/man/man1/olwmslave.1x olwmslave.1x )
( cd usr/openwin/man/man1 ; rm -rf openwin.1x )
( cd usr/openwin/man/man1 ; ln -sf /cdrom/live/usr/openwin/man/man1/openwin.1x openwin.1x )
( cd usr/openwin/man/man1 ; rm -rf owplaces.1x )
( cd usr/openwin/man/man1 ; ln -sf /cdrom/live/usr/openwin/man/man1/owplaces.1x owplaces.1x )
( cd usr/openwin/man/man1 ; rm -rf textedit.1x )
( cd usr/openwin/man/man1 ; ln -sf /cdrom/live/usr/openwin/man/man1/textedit.1x textedit.1x )
( cd usr/openwin/man/man1 ; rm -rf xtoolplaces.1x )
( cd usr/openwin/man/man1 ; ln -sf /cdrom/live/usr/openwin/man/man1/xtoolplaces.1x xtoolplaces.1x )
( cd usr/openwin/man/man1 ; rm -rf olvwm.1 )
( cd usr/openwin/man/man1 ; ln -sf /cdrom/live/usr/openwin/man/man1/olvwm.1 olvwm.1 )
( cd usr/openwin/man/man1 ; rm -rf olvwmrc.1 )
( cd usr/openwin/man/man1 ; ln -sf /cdrom/live/usr/openwin/man/man1/olvwmrc.1 olvwmrc.1 )
( cd usr/openwin/man/man1 ; rm -rf perf.1x )
( cd usr/openwin/man/man1 ; ln -sf /cdrom/live/usr/openwin/man/man1/perf.1x perf.1x )
( cd usr/openwin/share/doc/xview ; rm -rf xview-info )
( cd usr/openwin/share/doc/xview ; ln -sf /cdrom/live/usr/openwin/share/doc/xview/xview-info xview-info )
( cd usr/openwin/share/doc/xview ; rm -rf olgx_api.txt )
( cd usr/openwin/share/doc/xview ; ln -sf /cdrom/live/usr/openwin/share/doc/xview/olgx_api.txt olgx_api.txt )
( cd usr/openwin/share/doc/xview ; rm -rf sel_api.txt )
( cd usr/openwin/share/doc/xview ; ln -sf /cdrom/live/usr/openwin/share/doc/xview/sel_api.txt sel_api.txt )
( cd usr/openwin/share/doc/xview ; rm -rf dnd_api.txt )
( cd usr/openwin/share/doc/xview ; ln -sf /cdrom/live/usr/openwin/share/doc/xview/dnd_api.txt dnd_api.txt )
( cd usr/openwin/share/doc/xview ; rm -rf paper.ms )
( cd usr/openwin/share/doc/xview ; ln -sf /cdrom/live/usr/openwin/share/doc/xview/paper.ms paper.ms )
( cd usr/openwin/share/doc/xview ; rm -rf bugform )
( cd usr/openwin/share/doc/xview ; ln -sf /cdrom/live/usr/openwin/share/doc/xview/bugform bugform )
( cd usr/openwin/share/doc/xview ; rm -rf olgx_api.ps )
( cd usr/openwin/share/doc/xview ; ln -sf /cdrom/live/usr/openwin/share/doc/xview/olgx_api.ps olgx_api.ps )
( cd usr/openwin/share/doc/xview ; rm -rf whats_new.ps )
( cd usr/openwin/share/doc/xview ; ln -sf /cdrom/live/usr/openwin/share/doc/xview/whats_new.ps whats_new.ps )
( cd usr/openwin/share/locale/C/props ; rm -rf basic_setting )
( cd usr/openwin/share/locale/C/props ; ln -sf /cdrom/live/usr/openwin/share/locale/C/props/basic_setting basic_setting )
( cd usr/openwin/share/locale/C/props ; rm -rf C )
( cd usr/openwin/share/locale/C/props ; ln -sf /cdrom/live/usr/openwin/share/locale/C/props/C C )
( cd usr/openwin/lib/app-defaults ; rm -rf Xtoolplaces )
( cd usr/openwin/lib/app-defaults ; ln -sf /cdrom/live/usr/openwin/lib/app-defaults/Xtoolplaces Xtoolplaces )
( cd usr/openwin/lib/config ; rm -rf XView.cf )
( cd usr/openwin/lib/config ; ln -sf /cdrom/live/usr/openwin/lib/config/XView.cf XView.cf )
( cd usr/openwin/lib/config ; rm -rf XView.lib )
( cd usr/openwin/lib/config ; ln -sf /cdrom/live/usr/openwin/lib/config/XView.lib XView.lib )
( cd usr/openwin/lib/config ; rm -rf XView.obj )
( cd usr/openwin/lib/config ; ln -sf /cdrom/live/usr/openwin/lib/config/XView.obj XView.obj )
( cd usr/openwin/lib/config ; rm -rf XView.rules )
( cd usr/openwin/lib/config ; ln -sf /cdrom/live/usr/openwin/lib/config/XView.rules XView.rules )
( cd usr/openwin/lib/config ; rm -rf XView.tmpl )
( cd usr/openwin/lib/config ; ln -sf /cdrom/live/usr/openwin/lib/config/XView.tmpl XView.tmpl )
( cd usr/openwin/lib/config ; rm -rf XView.prog )
( cd usr/openwin/lib/config ; ln -sf /cdrom/live/usr/openwin/lib/config/XView.prog XView.prog )
( cd usr/openwin/lib/config ; rm -rf XView.rules.xstr )
( cd usr/openwin/lib/config ; ln -sf /cdrom/live/usr/openwin/lib/config/XView.rules.xstr XView.rules.xstr )
( cd usr/openwin/lib/help ; rm -rf textsw.info )
( cd usr/openwin/lib/help ; ln -sf /cdrom/live/usr/openwin/lib/help/textsw.info textsw.info )
( cd usr/openwin/lib/help ; rm -rf ttysw.info )
( cd usr/openwin/lib/help ; ln -sf /cdrom/live/usr/openwin/lib/help/ttysw.info ttysw.info )
( cd usr/openwin/lib/help ; rm -rf xview.info )
( cd usr/openwin/lib/help ; ln -sf /cdrom/live/usr/openwin/lib/help/xview.info xview.info )
( cd usr/openwin/lib/help ; rm -rf clock.info )
( cd usr/openwin/lib/help ; ln -sf /cdrom/live/usr/openwin/lib/help/clock.info clock.info )
( cd usr/openwin/lib/help ; rm -rf olwm.info )
( cd usr/openwin/lib/help ; ln -sf /cdrom/live/usr/openwin/lib/help/olwm.info olwm.info )
( cd usr/openwin/lib/help ; rm -rf props.info )
( cd usr/openwin/lib/help ; ln -sf /cdrom/live/usr/openwin/lib/help/props.info props.info )
( cd usr/openwin/lib/help ; rm -rf textedit.info )
( cd usr/openwin/lib/help ; ln -sf /cdrom/live/usr/openwin/lib/help/textedit.info textedit.info )
( cd usr/openwin/lib/help ; rm -rf workspace.info )
( cd usr/openwin/lib/help ; ln -sf /cdrom/live/usr/openwin/lib/help/workspace.info workspace.info )
( cd usr/openwin/lib/help ; rm -rf olvwm.info )
( cd usr/openwin/lib/help ; ln -sf /cdrom/live/usr/openwin/lib/help/olvwm.info olvwm.info )
( cd usr/openwin/lib/help ; rm -rf meminfo.info )
( cd usr/openwin/lib/help ; ln -sf /cdrom/live/usr/openwin/lib/help/meminfo.info meminfo.info )
( cd usr/openwin/lib/oldmenus ; rm -rf openwin-menu )
( cd usr/openwin/lib/oldmenus ; ln -sf /cdrom/live/usr/openwin/lib/oldmenus/openwin-menu openwin-menu )
( cd usr/openwin/lib/oldmenus ; rm -rf openwin-menu-d )
( cd usr/openwin/lib/oldmenus ; ln -sf /cdrom/live/usr/openwin/lib/oldmenus/openwin-menu-d openwin-menu-d )
( cd usr/openwin/lib/oldmenus ; rm -rf openwin-menu-e )
( cd usr/openwin/lib/oldmenus ; ln -sf /cdrom/live/usr/openwin/lib/oldmenus/openwin-menu-e openwin-menu-e )
( cd usr/openwin/lib/oldmenus ; rm -rf openwin-menu-g )
( cd usr/openwin/lib/oldmenus ; ln -sf /cdrom/live/usr/openwin/lib/oldmenus/openwin-menu-g openwin-menu-g )
( cd usr/openwin/lib/oldmenus ; rm -rf openwin-menu-s )
( cd usr/openwin/lib/oldmenus ; ln -sf /cdrom/live/usr/openwin/lib/oldmenus/openwin-menu-s openwin-menu-s )
( cd usr/openwin/lib/oldmenus ; rm -rf openwin-menu-t )
( cd usr/openwin/lib/oldmenus ; ln -sf /cdrom/live/usr/openwin/lib/oldmenus/openwin-menu-t openwin-menu-t )
( cd usr/openwin/lib/oldmenus ; rm -rf openwin-menu-u )
( cd usr/openwin/lib/oldmenus ; ln -sf /cdrom/live/usr/openwin/lib/oldmenus/openwin-menu-u openwin-menu-u )
( cd usr/openwin/lib/oldmenus ; rm -rf openwin-ss-ex )
( cd usr/openwin/lib/oldmenus ; ln -sf /cdrom/live/usr/openwin/lib/oldmenus/openwin-ss-ex openwin-ss-ex )
( cd usr/openwin/lib/oldmenus ; rm -rf openwin-uit )
( cd usr/openwin/lib/oldmenus ; ln -sf /cdrom/live/usr/openwin/lib/oldmenus/openwin-uit openwin-uit )
( cd usr/openwin/lib/oldmenus ; rm -rf openwin-xv-ex )
( cd usr/openwin/lib/oldmenus ; ln -sf /cdrom/live/usr/openwin/lib/oldmenus/openwin-xv-ex openwin-xv-ex )
